"use strict";

Object.defineProperty(exports, "__esModule", {
    value: true
});

var _createClass = function () { function defineProperties(target, props) { for (var i = 0; i < props.length; i++) { var descriptor = props[i]; descriptor.enumerable = descriptor.enumerable || false; descriptor.configurable = true; if ("value" in descriptor) descriptor.writable = true; Object.defineProperty(target, descriptor.key, descriptor); } } return function (Constructor, protoProps, staticProps) { if (protoProps) defineProperties(Constructor.prototype, protoProps); if (staticProps) defineProperties(Constructor, staticProps); return Constructor; }; }();

var _xcode = require("xcode");

var _xcode2 = _interopRequireDefault(_xcode);

var _fs = require("fs");

var _fs2 = _interopRequireDefault(_fs);

var _configuration = require("./configuration");

var _configuration2 = _interopRequireDefault(_configuration);

var _buildphase = require("./buildphase");

var _buildphase2 = _interopRequireDefault(_buildphase);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError("Cannot call a class as a function"); } }

/**
 * Base class to handle pbxproj file and basic project informations
 */
var Project = function () {
    function Project(path) {
        _classCallCheck(this, Project);

        this.projectPath = path;
        this.myProj = _xcode2.default.project(this.projectPath);

        this.myProj.parseSync();

        this.configuration = new _configuration2.default(this, this.myProj.hash);
        this.buildphase = new _buildphase2.default(this, this.myProj.hash);
    }

    /**
     * Get a specific project's target by name
     *
     * @example
     * const project = new Xcode('project.pbxproj');
     * const target = project.getTarget("TestProject");
     * console.log(target);
     *
     * project.getTargets().forEach((tg) => {
    *   console.log(project.getTarget(tg.name));
    * });
     *
     * @param {string} name The name of the target
     * @returns {*} The target (ref) or null if error
     */


    _createClass(Project, [{
        key: "getTarget",
        value: function getTarget(name) {
            var targets = this.myProj.hash.project.objects.PBXNativeTarget;

            for (var i in targets) {
                if (typeof i === "string" && i.indexOf("_comment") === -1) {
                    if (targets[i].name === name) {
                        return targets[i];
                    }
                }
            }

            return null;
        }

        /**
         * Get all project's targets
         *
         * @example
         * const project = new Xcode('project.pbxproj');
         * const targets = project.getTargets();
         * console.log(targets);
         *
         * @returns {Array} The targets (copy)
         */

    }, {
        key: "getTargets",
        value: function getTargets() {
            var targets = this.myProj.hash.project.objects.PBXNativeTarget;

            var keys = Object.keys(targets).filter(function (it) {
                return typeof it === "string" && it.indexOf("_comment") === -1;
            });

            return keys.map(function (it) {
                return targets[it];
            });
        }

        /**
         * Save all modifications
         *
         * @example
         * const project = new Xcode('project.pbxproj');
         * project.save();
         * project.save("project_second.pbxproj");
         *
         * @param {string} path The new project path (not required)
         */

    }, {
        key: "save",
        value: function save(path) {
            var newPath = path ? path : this.projectPath;

            _fs2.default.writeFileSync(newPath, this.myProj.writeSync());
        }

        /**
         * Return project as string (can be usefull to make bash redirections and other manipulations)
         *
         * @example
         * const project = new Xcode('project.pbxproj');
         * process.stdout.write(project.toString());
         *
         * @returns {string}
         */

    }, {
        key: "toString",
        value: function toString() {
            return this.myProj.writeSync().toString();
        }
    }]);

    return Project;
}();

exports.default = Project;